@@ -24,6 +24,6 @@ setup(name='FooPackage',
       entry_points="""
       # -*- Entry points: -*-
       [z3c.autoinclude.plugin]
-      target = basepackage
+      fleem = basepackage
       """,
       )
