@@ -23,5 +23,7 @@ setup(name='TestDirective',
       ],
       entry_points="""
       # -*- Entry points: -*-
+      [z3c.autoinclude.plugin]
+      target = basepackage
       """,
       )
