@@ -2,7 +2,6 @@ import os
 from pkg_resources import find_distributions
 from pprint import pformat
 import sys
-from zope.dottedname.resolve import resolve
 
 class DistributionManager(object):
     def __init__(self, dist):
@@ -54,7 +53,7 @@ def subpackageDottedNames(package_path, ns_dottedname=None):
                 result.append('%s.%s' % (ns_dottedname, subpackage_name))
             else:
                 result.append(subpackage_name)
-    return result
+    return sorted(result)
 
 def isPythonPackage(path):
     if not os.path.isdir(path):
